Type Definition collectd_plugin::de::DeResult

source ·
pub type DeResult<T> = Result<T, Error>;
Serde documentation shadows the std’s Result type which can be really confusing for Rust newcomers, so we compromise by creating an alias but prefixing with “De” to make it standout.